# -*- coding: utf-8 -*-

from PyQt4 import QtCore, QtGui
import DateWindow
from gettraff import GetTraff
import myconfig

class DateWindowExt( QtGui.QMainWindow ):
	def __init__(self, parent, widgetQDateTimeEdit ):
		QtGui.QMainWindow.__init__(self, parent)

		self.widgetQDateTimeEdit = widgetQDateTimeEdit

		try:
			self.setAttribute( QtCore.Qt.WA_Maemo5StackedWindow )
			self.setAttribute( QtCore.Qt.WA_Maemo5ShowProgressIndicator )
		except Exception, e:
			pass
			#print "DateWindowExt::__init__(): Exception setAttribute(): ", e

		self.ui = DateWindow.Ui_DateWindow()
		self.ui.setupUi( self )
		self.actionForm()
        
		self.ui.cal.showToday()

		#self.setWindowTitle( "Select date" )


	def actionForm(self):
		self.ui.bAcceptCal.clicked.connect( self.acceptDate )
		self.ui.bCancelCal.clicked.connect( self.hide )

	def acceptDate(self):
		D = self.ui.cal.selectedDate()
		self.widgetQDateTimeEdit.setDate( D )
		self.hide()

